######################################################################
# Xilinx Isolation Verification Tool Makefile 
# $Header: /devl/xcs/repo/env/InternalTools/IsolationVerifier/s/make.t,v 1.27.340.1 2013/01/24 01:14:52 jcorbett Exp $
######################################################################


APPNAME=ivt
EXTRA_CFLAGS = -DAPPNAME=${APPNAME}
!Execname ${APPNAME}
!Envfile ENVBIN = bin/${PLATFORM}
ENVBIN_EXEC = ${ENVBIN}/${EXEC}

# Needs to be a single line without extra spaces.
!Includes -i../i;${XILENV}

!m EXECOBJS = *.c:*.o

!m LIBOBJS = *.c:*.o

!Libraries                                \
  Pds:Pds_Exception                       \
  Pds:Pds_Pah                             \
  Pds:Pds_Pdm                             \
  Pds:Pds_Pdl                             \
  Pds:Pds_Tdm                             \
  Portability:Portability                 \
  Rf:Rf_FacadeBase                        \
  Rf:Rf_HelperBase                        \
  Rf:Rf_TilePinHelpersBase                \
  Utilities:Utilities                     \
  XCad:XCad_Cad                           \
  XCad:XCad_RMed                          \
  Xdm:Xdm                                 \
  ConstraintSystem:Cs                     \
  ConstraintSystem:Cs_DeviceHelpers       \
  Boost:Boost_Regex                       \
  PersonalityModule:PersonalityModule

######################################################################
# external targets
######################################################################

all: libexecs toolrel

devbld: libexecs toolrel

objs: ${EXECOBJS}

# builds executable to make it available in other package smokes
libexecs: ${EXEC}

toolrel: ${ENVBIN_EXEC}

clean:
	@${ECHO} Cleaning s directory...
	@${RMDIR} emake_data
!Rmfiles . *

# Create a bzip2 tar archive of all the include files. Assumes GNU
# utilities.
!m SRC=*.c
alldeps:
	${COMPILER} ${SRC} -MMD -MF ../all_dependencies.d \
            -H ${CFLAGS} ${EXTRA_CFLAGS} ${MYFLAGS} ${INCLUDES} -ansi  
	${GREP} --no-filename --only-matching "/build/[^ ]*" \
            ../all_dependencies.d|sort|uniq > ../includes.txt
	${TAR} --create --verbose --bzip2 \
             --files-from=../includes.txt --file ../ivt_includes.tbz

######################################################################
# internal targets
######################################################################

${EXEC}: ${EXECOBJS} ${EXE_VERSION} ${LDEPS}
	${RM} $@
	@${ECHO} Building $@ ...
	${EXLINKER} ${LINK_OUTPUT_FILE_FLAG} $(EXECOBJS) \
		${EXE_VERSION} ${LDIRS} ${LFLAGS} ${LLIBS} \
		${LINK_TERM_FLAGS}

${ENVBIN_EXEC}: ${EXEC}
!OC opt
	${CP} -p $< $@
!XC opt
!XC none

FORSCOPINGOPT=${STANDARDFORSCOPINGOPT}

# See # http://pdswiki/dev/index.php/Eureka_InternalTools_IsolationVerifier
# CP -p issue Possible vc80.pdb conflict -- debug Windows compiler
# creates vc80.pdb file, linker takes it in, but since multiple
# compilations occur, you can have an issue with one finishing after
# linker. Easy solution is to change the name of the pdb files output
# by the compiler to be unique.
!OC dbg
MYFLAGS +=  -Fd$(basename $@).pdb
!XC none

# individual module build rules
!X nt nt64
!d *.o : *.c
!r      @$(ECHO) ---------------- COMPILING $*.c ---------------------------
!r	@${RM} $@;
!r	${COMPILER} $*.c ${CFLAGS} ${EXTRA_CFLAGS} ${MYFLAGS} ${INCLUDES} -ansi -pedantic -Wall -W -Wconversion -Wcast-qual -Wwrite-strings

!O nt nt64
!d *.obj : ../s/*.c
!r      @$(ECHO) ---------------- COMPILING $*.c ---------------------------
!r	@${RM} $@;
!r	${COMPILER} ${EXTRA_CFLAGS} $(CFLAGS) ${MYFLAGS} $(INCLUDES) -Tp ../s/$*.c

# add the source links to object directory
!d *.c :
!r	@$(LN) ../s/$@ .
